#
# spec file for package lximage-qt
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lximage-qt
Version:        1.4.0
Release:        2.3
Summary:        LXQt Image Viewer
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Viewers
URL:            http://www.lxqt.org
Source:         https://github.com/lxqt/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        https://github.com/lxqt/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.1.0
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  lxqt-build-tools-devel >= 0.13.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(Qt5DBus) >= 5.15.0
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libfm-qt) >= %{version}
BuildRequires:  pkgconfig(lxqt) >= %{version}
BuildRequires:  pkgconfig(xfixes)
Requires(post): desktop-file-utils
Requires(pre):  desktop-file-utils

%description
Image Viewer for LXQt and Thumbnail Generator for PCManFM-Qt

%lang_package

%prep
%setup -q

%build
%cmake \
    -DUSE_QT5=ON \
    -DPULL_TRANSLATIONS=OFF

%install
%cmake_install

%suse_update_desktop_file -r %{name} Graphics Viewer RasterGraphics 2DGraphics Photography

%fdupes %{buildroot}%{_datadir}/%{name}

%find_lang %{name} --with-qt

%files
%license COPYING
%doc AUTHORS
%dir %{_datadir}/icons/hicolor/48x48
%dir %{_datadir}/icons/hicolor/48x48/apps
%{_bindir}/%{name}
%{_datadir}/applications/%{name}*.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.??g
%{_datadir}/metainfo/lximage-qt.metainfo.xml

%files lang -f %{name}.lang
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/translations
%{_datadir}/%{name}/translations/*

%changelog
* Mon Jan  1 2024 Shawn Dunn <sfalken@opensuse.org>
- Added %%dir declarations for icon directories to clear buildfail
* Sun Nov  5 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.4.0:
  * Added a minimal support for color spaces.
  * Removed ImageShack upload option (ImageShack requires a paid
    subscription now).
* Sat Apr 15 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.3.0:
  * Changed the app icon to SVG
  * Added a note on `kimageformats`
  * Fixed typos
* Sat Nov  5 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Update to 1.2.0:
  * Fixed visual glitches in painting cached images.
  * Added Sorting sub-menu to View menu.
* Thu Apr 28 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.1.0:
  * Restore maximized state (if any) on un-fullscreening.
  * Fixed capturing of an area of a screen that isn't positioned
    at the top left.
  * Removed the desktop file for taking screenshots (the screenshot
    functionality is kept, but LXQt's screenshot utility is Screengrab).
* Mon Nov  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.0.0:
  * Fixed bugs in image fitting, flipping and rotation.
  * Added options to hide/show main toolbar and/or menubar.
  * Added option to use system Trash.
  * Added option to change Thumbnail dimensions.
  * Added option to change the position of thumbnails dock.
  * Fixed wheel scrolling on image with touchpad.
  * Allowed direct image renaming (with shortcut).
  * Remember EXIF dock width.
  * Added command-line option for starting in fullscreen.
  * Allowed custom shortcuts to override hard-coded shortcuts.
  * Added option to disable image smoothing on zooming.
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.17.0:
  * Fitting images while navigating is made optional.
  * Options are added to Preferences dialog for thumbnails.
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Remove deprecated recommends on lang package
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.16.0:
  * Added image size and path to statusbar.
  * Added copy Path action.
  * Fixed memory leaks in annotations.
  * Show error message if saving with a format is not supported.
  * Added resize image feature.
  * Use QFlags default constructor.
  * Prevent users from defining ambiguous shortcuts.
  * Consult Qt for supported mimetypes.
  * Start app on screen with mouse cursor when opening image.
  * Added depreciation notice to screenshot command line options.
* Mon Apr 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Changed lximage-qt.keyring to tsujan's key
* Sat Apr 25 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 0.15.0
  * Added "Open With..." to File menu.
  * Added shortcut editor to Preferences.
  * Optionally show image outline.
  * Made maximum number of recent files configurable.
  * Keep zooming state on switching image.
  * Support uploading of unsaved images.
  * Jump forward when the image is deleted/renamed.
  * No auto-selection in thumbnail view.
  * Added command-line option to take a screenshot and save it to the directory without showing the GUI.
  * Several fixes.
* Fri Mar  1 2019 mvetter@suse.com
- Update to 0.14.1:
  * Only translations was changed
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.14.0:
  * Render image EXIF data (by Rndevfx)
  * Added confirmation dialog when using “Save as” with a filename without extension.
  * Add ImgBB upload provider
  * Add ability to annotate images
  * Add copy button to upload dialog
  * Implement MRU list
  * Update copyright block in source files
  * Fixed thumbnail selection (with deletion)
- Move translation from lxqt-l10n into package
* Tue May 22 2018 mvetter@suse.com
- Update to 0.7.0:
  * Bumped minor version to 7
  * Spanish translation update
  * Just made it compilable again
  * Removed not needed release.sh
  * CMake: Prevent in-source builds
  * fix some http->https
  * Fix some mentions of LXDE
  * Drop Qt foreach
  * cmake: Handle CMP0071
  * Add Spanish desktop entries
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.6.0:
  * Add ImageShack upload provider.
  * Fix warnings issued by GCC and Clang.
  * Ensure file is closed when upload finishes.
  * Make image URL read-only.
  * Update copyright in initial file comment for new additions.
  * Make QNetworkAccessManager static and fix initialization order in UploadDialog.
  * Add support for uploading files (fixes #98).
  * Bump versions
  * Don't export github templates
  * Don't use hardcoded install dir
  * Update CMakeLists.txt
  * Fix regression in thumbnail view
  * Add Lithuanian .desktop files
  * liblxqt don't fit here
  * Copied issue-template
  * Drops Qt5Core_VERSION_STRING
  * set Qt::AA_UseHighDpiPixmaps to true
  * MainWindow: Fix crash for quick image changes
  * Use GNUInstallDirs
  * jobs: Do proper error handling
  * Adapt to changes in libfm-qt(the c++11 port)
  * Use the new lxqt-build-tools new FindExif CMake module
  * Simpler code for ScreenshotSelectAreaGraphicsView class.
  * Change Screenshot select area green color by actual hightlight color. Use lximage-qt private variables style.
  * Adapt to C++11 and RAM improvements.
  * Screenshot captures an area of the screen.
  * Use const iterators
  * Bump year
  * File and folder DND Fixes https://github.com/lxde/lximage-qt/issues/69.
- Remove post and postun section because icon and desktop cache is now done automatically
- Change group to Productivity/Graphics/Viewers
* Fri Feb 24 2017 sfalken@opensuse.org
- Update to 0.5.1:
  * Bump patch version and (#82)
  * Create lximage-qt-screenshot_it.desktop (#83)
  * Add *da.desktop files
  * Desktop entry files: Fix typo in French translation
  * [MRG] Display first image when loading a directory (v2) (#75)
  * Desktop entry files: Add French translation
  * Use lxqt-build-tools
  * Use the new lxqt-build-tools package
  * Fixed A Cast (#71)
  * Remove cpack (#70)
* Sat Sep 24 2016 mvetter@suse.com
- Update to 0.5.0:
  * Bump version to 0.5.0 (#67)
  * Remove Core and Qt from Categories in desktop file (#64)
  * Extend README.md
  * Fix broken compatibility introduced by libfm-qt API changes. This closes lxde/lximage-qt#63.
  * Add Catalan translations
  * Quieten compiler warning
  * Code cleanup
  * Use LXQtCompilerSettings cmake module
  * Treat SVG files separately as SVG images
  * build: Update translations based on *.ui
  * Fix typo in Portuguese translation for desktop file
  * Fix typo in German translation for desktop file (#55)
  * build: Use external translations (#54)
  * ts-files removal (#53)
  * Hide cursor smartly in fullscreen mode
  * build: Use liblxqt's TranslateDesktop module
  * Adds support for GIF animation.
  * Implement an EOG-like behavior on starting By clicking on an image for the first time, the user wants to see it clearly with lximage-qt. So, the following behavior is implemented here:
  * Add --version command line option
  * Fix missing Russian translation in desktop file
  * Fix memory leak if taking screenshot with cursor
  * Polish translation updated
  * Another update
  * Improved Russian translation - thanks to uazure
  * Fix typo
  * Add Russian translation
  * Italian translation update
  * CMake: Adapt to libfm-qt Targets
  * Turn on C++11 support. This closes bug lxde/lximage-qt #36.
  * Exec should have an argument
  * all GPL files are (or any later)
  * Add release script
  * Update translations
  * Set the color table properly for scaled images
  * Add Greek (el) translation Remove needless country variant from language code
  * Corrected language code (de_DE -> de) of german translation, marked translations as done.
  * replace tabs with spaces
  * remove trailing spaces
  * replace glib with Qt for command-line parsing
  * Don't save file in private mode
  * Prevents the slideshow timeout to be set to 0 in the UI
  * Correctly include CMake modules in intree/superbuild mode
  * Remove lximage-qt from the Utilities category
  * Update README
  * Update .gitignore
  * Hungarian translations added
  * save and restore window size and maximized state
- Add keyring
- Remove lximage-qt-0.2.0-fix_desktop_file.patch: got upstreamed
* Wed Oct 29 2014 andrea@opensuse.org
- Fixed license tag according to legal team review
* Sat Oct 25 2014 andrea@opensuse.org
- new upstream version 0.3.0
* Tue May 13 2014 andrea@opensuse.org
- spec file clean up
* Mon May 12 2014 sfalken@opensuse.org
- Removed fedora spec, split into seperate subproject
  Del:  lximage-qt-Fedora_20.spec
* Sat May 10 2014 sfalken@opensuse.org
- Ran spec-cleaner on openSUSE specfile
* Fri May  9 2014 sfalken@opensuse.org
- Added specfile for Fedora_20
  Add: lximage-qt-Fedora_20.spec
* Fri May  9 2014 sfalken@opensuse.org
- Reapplied desktop file patch
  Add: 0001-fix_desktop_file.patch
* Fri May  9 2014 sfalken@opensuse.org
- Removed desktop file patch (upstream changes)
  Del:  0001-lximage_qt_screenshot_desktop.patch
* Fri May  9 2014 sfalken@opensuse.org
- Added tarball for new stable release
  Add:  lximage-qt-0.2.0.tar.xz
  Del:  _service
* Fri Apr  4 2014 sfalken@opensuse.org
- Updated patch to correct both desktop files
  Del: 0001-lximage_qt_screenshot_desktop.patch
  Add: 0001-lximage_qt_desktop_files.patch
* Fri Apr  4 2014 sfalken@opensuse.org
- Added patch to correct screenshot desktop file Categories
  Add: 0001-lximage_qt_screenshot_desktop.patch
* Fri Apr  4 2014 sfalken@opensuse.org
- Initial Source Upload
  Add: _service
  Add: lximage-qt.spec
  Add: lximage-qt.changes
